<?php
session_start();
require 'conn.php'; // Adjust the path as necessary

// Check if user is logged in
if (!isset($_SESSION['participant_id'])) {
    header('Location: login.php');
    exit;
}

// Fetch participant details
$participantId = $_SESSION['participant_id'];
$query = "SELECT * FROM coordconf WHERE id = :id";
$stmt = $conn->prepare($query);
$stmt->execute([':id' => $participantId]);
$participant = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$participant) {
    echo "Participant not found.";
    exit;
}

// Fetch Zoom link from the database
$queryZoom = "SELECT zoom_link FROM zoom WHERE id = 1"; // Adjust ID or query as necessary
$stmtZoom = $conn->prepare($queryZoom);
$stmtZoom->execute();
$zoomData = $stmtZoom->fetch(PDO::FETCH_ASSOC);
$zoomLink = htmlspecialchars($zoomData['zoom_link']); // Make sure to sanitize the link

// Generate certificate and payment slip download links
$certificateUrl = 'generate_certificate.php?id=' . htmlspecialchars($participant['id']);
$paymentSlipUrl = 'generate_payment_slip.php?id=' . htmlspecialchars($participant['id']);
$conferenceMaterialsUrl = 'materials.php';

// Generate profile image initials
function getInitials($fullname) {
    $names = explode(' ', $fullname);
    $initials = '';
    foreach ($names as $name) {
        $initials .= strtoupper(substr($name, 0, 1));
    }
    return $initials;
}

$profileImage = getInitials($participant['fullname']);
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Dashboard</title>
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <link href="imagesconf/icon2.png" rel="shortcut icon">
    <style>
        body {
            background: linear-gradient(135deg, #007bff, #0056b3, #003d7a);
            background-size: 300% 300%;
            animation: gradient 10s ease infinite;
            color: #fff;
            margin: 0;
            padding: 0;
        }
        .navbar {
            background: #0056b3;
        }
        .navbar-brand img {
            width: 100px;
        }
        .navbar-nav {
            margin-left: auto;
        }
        .card {
            background: rgba(255, 255, 255, 0.1);
            border-radius: 15px;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.2);
            padding: 2rem;
        }
        .profile-image {
            width: 100px;
            height: 100px;
            background: #ffffff;
            color: #007bff;
            display: flex;
            justify-content: center;
            align-items: center;
            border-radius: 50%;
            font-size: 2rem;
            margin: 0 auto;
            text-transform: uppercase;
        }
        .footer {
            background: #0056b3;
            color: #fff;
            text-align: center;
            padding: 1rem;
            position: fixed;
            width: 100%;
            bottom: 0;
        }
        @keyframes gradient {
            0% { background-position: 0% 0%; }
            50% { background-position: 100% 100%; }
            100% { background-position: 0% 0%; }
        }
    </style>
</head>
<body>
    <nav class="navbar navbar-expand-lg navbar-dark">
        <div class="container">
            <a class="navbar-brand" href="#">
                <img src="imagesconf/11th.png" alt="Logo">
            </a>
            <div class="ml-3">
                <span class="font-weight-bold">Registration Number: <?= htmlspecialchars($participant['registration_number']) ?></span>
            </div>
            <ul class="navbar-nav ml-auto">
                <li class="nav-item">
                    <a class="nav-link btn btn-secondary" href="logout2.php">Logout</a>
                </li>
            </ul>
        </div>
    </nav>

    <div class="container mt-5">
        <div class="card text-center">
            <div class="profile-image">
                <?= htmlspecialchars($profileImage) ?>
            </div>
            <h2 class="mt-3">Hello, <?= htmlspecialchars($participant['fullname']) ?>!</h2>
            <p>Click the buttons below to access the available resources:</p>
            
            <div class="row">
                <div class="col-6">
                    <a href="<?= $certificateUrl ?>" class="btn btn-primary btn-md btn-block" target="_blank">Download Your Certificate</a>
                </div>
                <div class="col-6">
                    <a href="<?= $paymentSlipUrl ?>" class="btn btn-success btn-md btn-block mt-2" target="_blank">
                        <?= $participant['status'] === 'approved' ? 'Download Payment Slip (PAID)' : 'Payment Slip (Unpaid)' ?>
                    </a>
                </div>
                <div class="col-6 mt-3">
                    <a href="<?= $conferenceMaterialsUrl ?>" class="btn btn-info btn-md btn-block" target="_blank">Download Conference Materials</a>
                </div>
                <div class="col-6 mt-3">
                    <button type="button" class="btn btn-warning btn-md btn-block" data-toggle="modal" data-target="#zoomModal">Join Zoom Meeting</button>
                </div>
            </div>
        </div>
    </div>

    <!-- Modal -->
    <div class="modal fade" id="zoomModal" tabindex="-1" role="dialog" aria-labelledby="zoomModalLabel" aria-hidden="true">
        <div class="modal-dialog modal-dialog-centered modal-lg" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="zoomModalLabel">Welcome to the 2024 Annual Coordinators Conference</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <div class="modal-body text-center">
                    <!-- <img src="imagesconf/conf.jpg" alt="Conference" class="img-fluid rounded mb-3" style="max-width: 100%; height: auto;">
                    <p class="mt-3">Theme: Be Prepared</p> -->
                    <p>Click the button below to join the live Zoom meeting:</p>
                    <iframe src="<?= $zoomLink ?>" width="100%" height="600px" frameborder="0" allow="fullscreen; accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture"></iframe>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                </div>
            </div>
        </div>
    </div>

    <div class="footer">
        <p>&copy; <?= date('Y') ?> RCCG DTCE | CO-ORDINATORS CONFERENCE. All rights reserved.</p>
    </div>

    <!-- Include Bootstrap and jQuery scripts -->
    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.9.2/dist/umd/popper.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
</body>
</html>
