<?php
include 'conn.php'; // Database connection

// Define the number of items per page
$itemsPerPage = 8;

// Get the current page number from the query parameter or set default to 1
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$offset = ($page - 1) * $itemsPerPage;

// Fetch the total number of items
$totalStmt = $conn->query("SELECT COUNT(*) FROM confgallery");
$totalItems = $totalStmt->fetchColumn();
$totalPages = ceil($totalItems / $itemsPerPage);

// If there are no items in the gallery, return an empty response
if ($totalItems == 0) {
    echo json_encode([
        'items' => '',
        'pagination' => ''
    ]);
    exit();
}

// Fetch gallery images and videos for the current page
$stmt = $conn->prepare("SELECT * FROM confgallery ORDER BY id ASC LIMIT :offset, :limit");
$stmt->bindParam(':offset', $offset, PDO::PARAM_INT);
$stmt->bindParam(':limit', $itemsPerPage, PDO::PARAM_INT);
$stmt->execute();
$items = $stmt->fetchAll();

// Generate HTML for images and videos
$itemHtml = '';
foreach ($items as $item) {
    if (!empty($item['video_url'])) {
        // Video item
        $itemHtml .= '<div class="col-lg-3 col-md-4">
            <div class="image">
                <img src="' . htmlspecialchars($item['thumbnail_path']) . '" alt="video-thumbnail" class="img-fluid">
                <div class="primary-overlay">
                    <a class="video-link" data-video-src="https://www.youtube.com/embed/' . htmlspecialchars($item['video_url']) . '" href="#"><i class="fa fa-video-camera"></i></a>
                </div>
            </div>
        </div>';
    } else {
        // Image item
        $itemHtml .= '<div class="col-lg-3 col-md-4">
            <div class="image">
                <img src="' . htmlspecialchars($item['image_path']) . '" alt="gallery-image" class="img-fluid">
                <div class="primary-overlay">
                    <a class="image-popup" data-effect="mfp-with-zoom" href="' . htmlspecialchars($item['image_path']) . '"><i class="fa fa-picture-o"></i></a>
                </div>
            </div>
        </div>';
    }
}

// Generate HTML for pagination
$paginationHtml = '<nav aria-label="Page navigation example" class="d-flex justify-content-center mt-4">
    <ul class="pagination">';
for ($i = 1; $i <= $totalPages; $i++) {
    $activeClass = ($i == $page) ? 'active' : ''; // Set active class for the current page
    $paginationHtml .= '<li class="page-item ' . $activeClass . '"><a class="page-link pagination-link" href="#" data-page="' . $i . '">' . $i . '</a></li>';
}
$paginationHtml .= '</ul></nav>';

// Return JSON response
echo json_encode([
    'items' => $itemHtml,
    'pagination' => $paginationHtml
]);
?>
