<?php
session_start();
require 'conn.php'; // Adjust the path as necessary

// Check if user is logged in
if (!isset($_SESSION['participant_id'])) {
    header('Location: login.php');
    exit;
}

$participantId = $_SESSION['participant_id'];
$query = "SELECT * FROM coordconf WHERE id = :id";
$stmt = $conn->prepare($query);
$stmt->execute([':id' => $participantId]);
$participant = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$participant) {
    echo "Participant not found.";
    exit;
}

// Function to convert number to words
function convertNumberToWords($number) {
    $number = intval($number);
    $units = array(
        0 => 'Zero',
        1 => 'One',
        2 => 'Two',
        3 => 'Three',
        4 => 'Four',
        5 => 'Five',
        6 => 'Six',
        7 => 'Seven',
        8 => 'Eight',
        9 => 'Nine',
        10 => 'Ten',
        11 => 'Eleven',
        12 => 'Twelve',
        13 => 'Thirteen',
        14 => 'Fourteen',
        15 => 'Fifteen',
        16 => 'Sixteen',
        17 => 'Seventeen',
        18 => 'Eighteen',
        19 => 'Nineteen'
    );
    $tens = array(
        20 => 'Twenty',
        30 => 'Thirty',
        40 => 'Forty',
        50 => 'Fifty',
        60 => 'Sixty',
        70 => 'Seventy',
        80 => 'Eighty',
        90 => 'Ninety'
    );
    $hundreds = array(
        100 => 'Hundred',
        1000 => 'Thousand'
    );

    if ($number < 20) {
        return $units[$number];
    } elseif ($number < 100) {
        $t = (int)($number / 10) * 10;
        $u = $number % 10;
        return $tens[$t] . ($u ? '-' . $units[$u] : '');
    } elseif ($number < 1000) {
        $h = (int)($number / 100);
        $r = $number % 100;
        return $units[$h] . ' ' . $hundreds[100] . ($r ? ' and ' . convertNumberToWords($r) : '');
    } elseif ($number < 100000) {
        $t = (int)($number / 1000);
        $r = $number % 1000;
        return convertNumberToWords($t) . ' Thousand' . ($r ? ' ' . convertNumberToWords($r) : '');
    } else {
        return 'Number too large';
    }
}

// Amount Paid
$amountPaid = $participant['amount_paid'];
$amountInWords = convertNumberToWords($amountPaid) . ' Naira Only';

// Create payment slip
require_once('tcpdf/tcpdf.php'); // Adjust the path as necessary

$pdf = new TCPDF();
$pdf->AddPage();
$pdf->SetFont('helvetica', '', 12);

// Add Logo above the company name
$pdf->Image('imagesconf/conf.jpg', 85, 10, 40, '', 'JPG', '', 'T', false, 300, '', false, false, 0, false, false, false);

// Move the Y position down to avoid overlapping the text with the logo
$pdf->SetY(55);

// Company Information
$pdf->SetFont('helvetica', 'B', 14);
$pdf->Cell(0, 10, 'THE REDEEMED CHRISTIAN CHURCH OF GOD', 0, 1, 'C');
$pdf->Cell(0, 10, 'DIRECTORATE OF TEENS AND CHURCH EDUCATION', 0, 1, 'C');
$pdf->Cell(0, 10, 'GLORY ARENA, KM 46, LAGOS-IBADAN EXPRESSWAY', 0, 1, 'C');
$pdf->Cell(0, 10, 'REDEMPTION CITY, OGUN STATE', 0, 1, 'C');
$pdf->Cell(0, 10, 'Website: www.rccgjuniorchurch.org    Email: rccgdtce@gmail.com', 0, 1, 'C');
$pdf->Ln(10);

// Payment Slip Title
$pdf->SetFont('helvetica', 'B', 16);
$pdf->Cell(0, 10, 'PAYMENT RECEIPT FOR', 0, 1, 'C');
$pdf->Cell(0, 10, '2024 ANNUAL JUNIOR CHURCH CO-ORDINATORS CONFERENCE', 0, 1, 'C');
$pdf->Cell(0, 10, 'THEME: BE PREPARED', 0, 1, 'C');
$pdf->Ln(10);

// Payment Slip Content
$pdf->SetFont('helvetica', '', 12);
$pdf->Cell(0, 10, 'Registration Number: ' . htmlspecialchars($participant['registration_number']), 0, 1, 'C');
$pdf->Cell(0, 10, 'Name: ' . htmlspecialchars($participant['fullname']), 0, 1, 'C');
$pdf->Cell(0, 10, 'Status: ' . ($participant['status'] === 'approved' ? 'PAID' : 'UNPAID'), 0, 1, 'C');
$pdf->Cell(0, 10, 'Amount Paid: ' . number_format($amountPaid) . ' Naira', 0, 1, 'C');
$pdf->Ln(10);
$pdf->Cell(0, 10, 'Amount in Words: ' . $amountInWords, 0, 1, 'C');
$pdf->Ln(10);
$pdf->Cell(0, 10, 'Thank you for your payment. If you have any questions, please contact us.', 0, 1, 'C');

// Output the PDF
$pdf->Output('payment_slip.pdf', 'I');

?>
