<?php
session_start(); // Start the session

// Check if the admin is logged in
if (!isset($_SESSION['admin_id'])) {
    // If not logged in, redirect to the login page
    header("Location: admin_login.php");
    exit();
}

// Retrieve admin details from session variables
$admin_name = $_SESSION['admin_name'];
$admin_email = $_SESSION['admin_email'];
$admin_initials = $_SESSION['admin_initials'];
include 'conn.php'; // Database connection

// Handle status update
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['approve'])) {
    $id = $_POST['id'];
    $stmt = $conn->prepare("UPDATE coordconf SET status = 'Approved' WHERE id = ?");
    $stmt->execute([$id]);

    // Fetch the registration number of the approved participant
    $stmt = $conn->prepare("SELECT registration_number FROM coordconf WHERE id = ?");
    $stmt->execute([$id]);
    $participant = $stmt->fetch();
    $registrationNumber = $participant['registration_number'] ?? '';

    // Add a flag to notify success
    $successMessage = "Participant ID $id with Registration Number $registrationNumber has been approved.";
}

// Fetch participants
$stmt = $conn->prepare("SELECT * FROM coordconf ORDER BY region, fullname");
$stmt->execute();
$participants = $stmt->fetchAll();
?>

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Dashboard</title>
    <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.3/css/all.min.css" rel="stylesheet">
    <link href="https://cdn.datatables.net/1.10.24/css/jquery.dataTables.min.css" rel="stylesheet">
    <link href="imagesconf/icon2.png" rel="shortcut icon">
    <style>
    body {
        font-family: Arial, sans-serif;
        background-color: #f8f9fa;
    }

    .navbar {
        background-color: #343a40;
    }

    .navbar-brand {
        color: #fff;
        font-weight: bold;
    }

    .sidebar {
        height: 100vh;
        background-color: #343a40;
        padding-top: 20px;
    }

    .sidebar a {
        color: #ddd;
        padding: 15px;
        display: block;
        font-size: 16px;
        text-decoration: none;
    }

    .sidebar a:hover {
        background-color: #495057;
        color: #fff;
    }

    .content {
        padding: 20px;
        margin-left: 250px;
    }

    .card-header {
        background-color: #186F45;
        color: white;
        text-align: center;
    }

    .btn-primary {
        background-color: #186F45;
        border-color: #186F45;
    }

    .btn-primary:hover {
        background-color: #145536;
        border-color: #145536;
    }

    .content {
        padding: 20px;
    }

    .card {
        border: none;
        border-radius: 10px;
        box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
    }

    .card-header {
        background-color: black;
        border-bottom: 1px solid #dee2e6;
        border-top-left-radius: 10px;
        border-top-right-radius: 10px;
        padding: 15px;
    }

    .card-body {
        padding: 20px;
    }

    .table img {
        max-width: 100px;
        height: auto;
    }

    .btn-block {
        width: 100%;
    }

    .status-pending {
        background-color: #f0ad4e;
        /* Orange background for Pending status */
        color: #fff;
        /* White text color */
    }

    .status-approved {
        background-color: green;
        /* Blue background for Approved status */
        color: #fff;
        /* White text color */
    }

    .status-badge {
        font-size: 0.9em;
        padding: 0.3em 0.6em;
        border-radius: 0.3em;
        display: inline-block;
        text-align: center;
    }

    .custom-card {
        width: 100%;
        margin: 0 auto;
        padding: 20px;
    }

    .table-container {
        max-height: 600px;
        /* Adjust as needed */
        overflow-y: auto;
    }

    .profile-image {
        display: inline-block;
        width: 40px;
        height: 40px;
        background-color: #007bff;
        color: #fff;
        text-align: center;
        line-height: 40px;
        border-radius: 50%;
        font-weight: bold;
        margin-right: 10px;
    }

    .profile-image span {
        font-size: 16px;
        text-transform: uppercase;
    }
    </style>
</head>

<body>

    <!-- Navbar -->
    <!-- Navbar -->
    <nav class="navbar navbar-expand-lg navbar-dark">
        <a class="navbar-brand" href="#">Admin Dashboard</a>
        <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarNav"
            aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbarNav">
            <ul class="navbar-nav ml-auto">
                <!-- Profile Image (Initials) -->
                <li class="nav-item">
                    <div class="profile-image">
                        <span><?php echo $_SESSION['admin_initials']; ?></span>
                    </div>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="#"><i class="fas fa-user-circle"></i> Profile</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="logout.php"><i class="fas fa-sign-out-alt"></i> Logout</a>
                </li>
            </ul>
        </div>
    </nav>
    <!-- Sidebar -->
    <div class="d-flex">
    <div class="sidebar">
        <a href="admin_main_header.php"><i class="fas fa-bookmark"></i> Add Main Header</a>

        <?php if ($_SESSION['user_type'] == 'superadmin') : ?>
            <!-- Show Approve Admins only for superadmin -->
            <a href="admin_approval.php"><i class="fas fa-book"></i> Approve Admins</a>
        <?php endif; ?>

        <!-- Show all other menus for both admin and superadmin -->
        <a href="about_admin.php"><i class="fas fa-tachometer-alt"></i> Add About</a>
        <a href="admin.php"><i class="fas fa-tachometer-alt"></i> Add Speakers</a>
        <a href="manage_speakers.php"><i class="fas fa-user"></i> Manage Speakers</a>
        <a href="manage_registrants.php"><i class="fas fa-user"></i> Manage Registrants</a>
        <a href="admin_schedules.php"><i class="fas fa-calendar"></i> Manage Event Schedule</a>
        <a href="admin_upload.php"><i class="fas fa-camera"></i> Add Gallery</a>
        <a href="confgallery.php"><i class="fas fa-camera"></i> Manage Gallery</a>
        <a href="admin_sponsors.php"><i class="fas fa-user"></i> Manage Sponsors</a>
        <a href="manage_sponsors.php"><i class="fas fa-briefcase"></i> List of Sponsors</a>
        <a href="admin_news.php"><i class="fas fa-book"></i> Manage News</a>
        <a href="price_table.php"><i class="fas fa-table"></i> Manage Price Table</a>
        <a href="zoom.php"><i class="fas fa-video"></i> Add Zoom Link</a>
        <a href="#"><i class="fas fa-cog"></i> Settings</a>
        <a href="#"><i class="fas fa-question-circle"></i> Help</a>
    </div>


        <!-- Admin Details Section -->
        <div class="container mt-5 flex-grow-1">
            <div class="card">
                <div class="card-header">
                    Admin Details
                </div>
                <div class="card-body">
                    <h2>Welcome, <?php echo $admin_name; ?></h2>
                    <p>Email: <?php echo $admin_email; ?></p>
                    <p>Initials: <?php echo $admin_initials; ?></p>
                </div>
            </div>

            <nav class="navbar navbar-expand-lg navbar-dark">
        <a class="navbar-brand" href="#">
            <img src="imagesconf/11th.png" alt="Logo">
        </a>
        <ul class="navbar-nav ml-auto">
            <li class="nav-item">
                <a class="nav-link btn btn-secondary" href="admin.php">Back to Dashboard</a>
            </li>
        </ul>
    </nav>

            <!----Addd Content----->
            <div class="container mt-5">
                <h2>Manage Event Participants</h2>

                <div class="card custom-card">
                    <div class="card-header">
                        Participants List
                    </div>
                    <div class="card-body table-container">
                        <table id="participantsTable" class="table table-bordered">
                            <thead>
                                <tr>
                                    <th>ID</th>
                                    <th>Full Name</th>
                                    <th>Region</th>
                                    <th>Gender</th>
                                    <th>Position</th>
                                    <th>Amount Paid</th>
                                    <th>Phone Number</th>
                                    <th>Province</th>
                                    <th>Registration Number</th>
                                    <th>Status</th>
                                    <th>Actions</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($participants as $participant): ?>
                                <tr>
                                    <td><?= htmlspecialchars($participant['id']) ?></td>
                                    <td><?= htmlspecialchars($participant['fullname']) ?></td>
                                    <td><?= htmlspecialchars($participant['region']) ?></td>
                                    <td><?= htmlspecialchars($participant['gender']) ?></td>
                                    <td><?= htmlspecialchars($participant['position']) ?></td>
                                    <td><?= number_format($participant['amount_paid'], 2) ?></td>
                                    <td><?= htmlspecialchars($participant['phone_number']) ?></td>
                                    <td><?= htmlspecialchars($participant['province']) ?></td>
                                    <td><?= htmlspecialchars($participant['registration_number']) ?></td>
                                    <td>
                                        <?php if ($participant['status'] === 'Pending'): ?>
                                        <span class="status-badge status-pending">Pending</span>
                                        <?php else: ?>
                                        <span class="status-badge status-approved">Approved</span>
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <?php if ($participant['status'] === 'Pending'): ?>
                                        <form method="POST" action="" style="display:inline;">
                                            <input type="hidden" name="id"
                                                value="<?= htmlspecialchars($participant['id']) ?>">
                                            <button type="submit" name="approve"
                                                class="btn btn-success btn-sm">Approve</button>
                                        </form>
                                        <?php else: ?>
                                        <button class="btn btn-secondary btn-sm" disabled>Approved</button>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>



            <!-- Bootstrap and FontAwesome Scripts -->
            <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
            <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
            <script src="https://cdn.datatables.net/1.10.24/js/jquery.dataTables.min.js"></script>
            <script src="https://cdn.jsdelivr.net/npm/bootstrap@4.5.2/dist/js/bootstrap.bundle.min.js"></script>
            <script>
            $(document).ready(function() {
                $('#participantsTable').DataTable({
                    "paging": true,
                    "searching": true,
                    "ordering": true,
                    "info": true,
                    "pageLength": 10
                });
                <?php if (isset($successMessage)): ?>
                alert("<?= addslashes($successMessage) ?>");
                <?php endif; ?>
            });
            </script>
</body>

</html>