<?php
// Include your database connection
include 'conn.php';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get the news ID and comment from the form submission
    $newsId = isset($_POST['id']) ? (int)$_POST['id'] : 0;
    $comment = isset($_POST['comment']) ? trim($_POST['comment']) : '';

    // Validate the comment and news ID
    if ($newsId > 0 && !empty($comment)) {
        // Fetch the current comments and comment count from the confnews table
        $query = "SELECT comments, comments_count FROM confnews WHERE id = :id";
        $stmt = $conn->prepare($query);
        $stmt->bindParam(':id', $newsId, PDO::PARAM_INT);
        $stmt->execute();
        $news = $stmt->fetch(PDO::FETCH_ASSOC);

        if ($news) {
            // Add the new comment to the existing comments
            $currentComments = $news['comments'];
            if (!empty($currentComments)) {
                $updatedComments = $currentComments . "\n" . $comment;  // Append the new comment to the existing ones
            } else {
                $updatedComments = $comment;  // If no comments yet, this will be the first comment
            }

            // Update the comment count by incrementing the current count
            $commentsCount = (int)$news['comments_count'] + 1;

            // Update the confnews table with the new comments and comment count
            $updateQuery = "UPDATE confnews SET comments = :comments, comments_count = :comments_count WHERE id = :id";
            $updateStmt = $conn->prepare($updateQuery);
            $updateStmt->bindParam(':comments', $updatedComments, PDO::PARAM_STR);
            $updateStmt->bindParam(':comments_count', $commentsCount, PDO::PARAM_INT);
            $updateStmt->bindParam(':id', $newsId, PDO::PARAM_INT);

            if ($updateStmt->execute()) {
                // Redirect back to the news page or send a success message
                header("Location: index.php?success=comment_added");
                exit();
            } else {
                // Handle failure in updating the comments
                echo "Failed to save comment. Please try again.";
            }
        } else {
            // Handle the case where the news article was not found
            echo "News not found.";
        }
    } else {
        // Handle invalid input
        echo "Invalid comment or news ID.";
    }
} else {
    // Handle the case where the request method is not POST
    echo "Invalid request.";
}
?>
